body {
    background-color: #6c7a86; /* Greyish-blueish background color */
  }
  
  .message-container {
    position: fixed;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    padding: 20px;
    background-color: #ffffff; /* White background for the message */
    box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1); /* Add a subtle shadow */
    border-radius: 5px;
    text-align: center;
  }
  
  .message {
    margin: 0;
    padding: 10px;
    font-size: 18px;
    color: #333333; /* Dark text color */
  }
  