{% load static %}
<html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Email Verification</title>
        <link rel="stylesheet" href="{% static 'css/email_verify_css.css' %}">
        <meta name="description" content="">
        <meta name="keywords" content="">
    </head>
    <body>
        {% block email_verify_content %}
        {% endblock email_verify_content %}
    </body>
</html>