{% extends "email_verify/base.html" %}
{% block email_verify_content %}
    <div class="message-container">
        <div class="message">
            <h1>Your e-mail has been verified.</h1>
            <p>
                <a href="{{ main_page }}">Click here</a> to go to main page
            </p>
        </div>
    </div>
{% endblock email_verify_content %}
